@@ -9,7 +9,7 @@
 #
 package Reindeer;
 {
-  $Reindeer::VERSION = '0.009'; # TRIAL
+  $Reindeer::VERSION = '0.014'; # TRIAL
 }
 
 # ABSTRACT: Moose with more antlers
@@ -22,6 +22,7 @@ use Moose::Exporter;
 use Class::Load;
 
 use MooseX::Traits ();
+use Moose::Util::TypeConstraints ();
 
 my (undef, undef, $init_meta) = Moose::Exporter->build_import_methods(
     install => [ qw{ import unimport } ],
@@ -37,6 +38,12 @@ sub init_meta {
     my ($class, %options) = @_;
     my $for_class = $options{for_class};
 
+    if ($] >= 5.010) {
+
+        eval 'use feature';
+        feature->import(':5.10');
+    }
+
     ### $for_class
     Moose->init_meta(for_class => $for_class);
 
@@ -44,6 +51,10 @@ sub init_meta {
     Reindeer::Util->import_type_libraries({ -into => $for_class });
     Path::Class->export_to_level(1);
     Try::Tiny->export_to_level(1);
+    Moose::Util::TypeConstraints->import(
+        { into => $for_class },
+        qw{ class_type role_type duck_type },
+    );
     MooseX::MarkAsMethods->import({ into => $for_class }, autoclean => 1);
 
     goto $init_meta if $init_meta;
@@ -51,19 +62,22 @@ sub init_meta {
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl AutoDestruct MultiInitArg UndefTolerant autoclean rwp ttl
+metaclass Specifing
+
 =head1 NAME
 
 Reindeer - Moose with more antlers
 
 =head1 VERSION
 
-This document describes version 0.009 of Reindeer - released April 07, 2012 as part of Reindeer.
+This document describes version 0.014 of Reindeer - released August 31, 2012 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -87,15 +101,6 @@ a number of the more useful/popular extensions already applied.  Reindeer is a
 drop-in replacement for your "use Moose" line, that behaves in the exact same
 way... Just with more pointy antlers.
 
-=for stopwords AutoDestruct
-MultiInitArg
-UndefTolerant
-autoclean
-rwp
-ttl
-metaclass
-Specifing
-
 =for Pod::Coverage     init_meta
 
 =head1 EARLY RELEASE!
@@ -221,11 +226,58 @@ For an attribute named "_foo":
 This naming scheme, in which the trigger is always private, is the same as the
 builder naming scheme (just with a different prefix).
 
+=head2 builder => sub { ... }
+
+Passing a coderef to builder will cause that coderef to be installed in the
+class this attribute is associated with the name you'd expect, and
+C<builder =E<gt> 1> to be set.
+
+e.g., in your class,
+
+    has foo => (is => 'ro', builder => sub { 'bar!' });
+
+...is effectively the same as...
+
+    has foo => (is => 'ro', builder => '_build_foo');
+    sub _build_foo { 'bar!' }
+
 =head1 NEW KEYWORDS (SUGAR)
 
 In addition to all sugar provided by L<Moose> (e.g. has, with, extends), we
 provide a couple new keywords.
 
+=head2 B<class_type ($class, ?$options)>
+
+Creates a new subtype of C<Object> with the name C<$class> and the
+metaclass L<Moose::Meta::TypeConstraint::Class>.
+
+  # Create a type called 'Box' which tests for objects which ->isa('Box')
+  class_type 'Box';
+
+By default, the name of the type and the name of the class are the same, but
+you can specify both separately.
+
+  # Create a type called 'Box' which tests for objects which ->isa('ObjectLibrary::Box');
+  class_type 'Box', { class => 'ObjectLibrary::Box' };
+
+(See also L<Moose::Util::TypeConstraints>.)
+
+=head2 B<role_type ($role, ?$options)>
+
+Creates a C<Role> type constraint with the name C<$role> and the
+metaclass L<Moose::Meta::TypeConstraint::Role>.
+
+  # Create a type called 'Walks' which tests for objects which ->does('Walks')
+  role_type 'Walks';
+
+By default, the name of the type and the name of the role are the same, but
+you can specify both separately.
+
+  # Create a type called 'Walks' which tests for objects which ->does('MooseX::Role::Walks');
+  role_type 'Walks', { role => 'MooseX::Role::Walks' };
+
+(See also L<Moose::Util::TypeConstraints>.)
+
 =head2 class_has => (...)
 
 Exactly like L<Moose/has>, but operates at the class (rather than instance)
@@ -291,6 +343,38 @@ defined).
 
 See L<MooseX::AutoDestruct> for more information.
 
+=head2 ENV
+
+This is a Moose attribute trait that you use when you want the default value
+for an attribute to be populated from the %ENV hash.  So, for example if you
+have set the environment variable USERNAME to 'John' you can do:
+
+    package MyApp::MyClass;
+
+    use Moose;
+    use MooseX::Attribute::ENV;
+
+    has 'username' => (is=>'ro', traits=>['ENV']);
+
+    package main;
+
+    my $myclass = MyApp::MyClass->new();
+
+    print $myclass->username; # STDOUT => 'John';
+
+This is basically similar functionality to something like:
+
+    has 'attr' => (
+            is=>'ro',
+            default=> sub {
+                    $ENV{uc 'attr'};
+            },
+    );
+
+If the named key isn't found in %ENV, then defaults will execute as normal.
+
+See L<MooseX::Attribute::ENV> for more information.
+
 =head2 MultiInitArg
 
     has 'data' => (
@@ -505,7 +589,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
