@@ -9,7 +9,7 @@
 #
 package Reindeer::Role;
 {
-  $Reindeer::Role::VERSION = '0.009'; # TRIAL
+  $Reindeer::Role::VERSION = '0.014'; # TRIAL
 }
 
 # ABSTRACT: Reindeer in role form
@@ -32,11 +32,21 @@ sub init_meta {
     my ($class, %options) = @_;
     my $for_class = $options{for_class};
 
+    if ($] >= 5.010) {
+
+        eval 'use feature';
+        feature->import(':5.10');
+    }
+
     ### $for_class
     Moose::Role->init_meta(for_class => $for_class);
     Reindeer::Util->import_type_libraries({ -into => $for_class });
     Path::Class->export_to_level(1);
     Try::Tiny->export_to_level(1);
+    Moose::Util::TypeConstraints->import(
+        { into => $for_class },
+        qw{ class_type role_type duck_type },
+    );
     MooseX::MarkAsMethods->import({ into => $for_class }, autoclean => 1);
 
     goto $init_meta if defined $init_meta;
@@ -44,19 +54,21 @@ sub init_meta {
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl
+
 =head1 NAME
 
 Reindeer::Role - Reindeer in role form
 
 =head1 VERSION
 
-This document describes version 0.009 of Reindeer::Role - released April 07, 2012 as part of Reindeer.
+This document describes version 0.014 of Reindeer::Role - released August 31, 2012 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -113,7 +125,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
