@@ -9,7 +9,7 @@
 #
 package Reindeer::Util;
 {
-  $Reindeer::Util::VERSION = '0.009'; # TRIAL
+  $Reindeer::Util::VERSION = '0.014'; # TRIAL
 }
 
 # ABSTRACT: Common and utility functions for Reindeer
@@ -26,7 +26,7 @@ use Class::Load 'load_class';
 use Moose 1.15                              ( );
 use MooseX::AlwaysCoerce 0.16               ( );
 use MooseX::AbstractMethod 0.003            ( );
-use MooseX::AttributeShortcuts 0.006        ( );
+use MooseX::AttributeShortcuts 0.015        ( );
 use MooseX::ClassAttribute 0.26             ( );
 use MooseX::CurriedDelegation               ( );
 use MooseX::LazyRequire 0.07                ( );
@@ -38,7 +38,7 @@ use MooseX::Types::Common::String 0.001004  ( );
 use MooseX::Types::Common::Numeric 0.001004 ( );
 use MooseX::Types::LoadableClass 0.006      ( );
 use MooseX::Types::Path::Class 0.05         ( );
-use MooseX::Types::Tied::Hash::IxHash 0.002 ( );
+use MooseX::Types::Tied::Hash::IxHash 0.003 ( );
 
 use Path::Class 0.24 ( );
 use Try::Tiny 0.11   ( );
@@ -56,7 +56,7 @@ sub trait_aliases {
         [ 'MooseX::TrackDirty::Attributes::Trait::Attribute' => 'TrackDirty'    ],
         [ 'MooseX::UndefTolerant::Attribute'                 => 'UndefTolerant' ],
 
-        # LazyRequire doesn't export a trait_alias, so let's create one
+        # these don't export a trait_alias, so let's create one
         'MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire',
 
         # this one is a little funky, in that it replaces the accessor
@@ -68,13 +68,15 @@ sub trait_aliases {
 # If an extension doesn't have a trait that's directly loadable, we build subs
 # to do it here.
 
+sub ENV     { _lazy('MooseX::Attribute::ENV', 'MooseX::Attribute::ENV') }
 sub SetOnce { _lazy('MooseX::SetOnce', 'MooseX::SetOnce::Attribute') }
-sub _lazy { load_class(shift); shift }
+sub _lazy   { load_class(shift); shift }
 
 
 sub as_is {
 
     return (
+        \&ENV,
         \&SetOnce,
     );
 }
@@ -126,19 +128,21 @@ sub type_libraries {
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl
+
 =head1 NAME
 
 Reindeer::Util - Common and utility functions for Reindeer
 
 =head1 VERSION
 
-This document describes version 0.009 of Reindeer::Util - released April 07, 2012 as part of Reindeer.
+This document describes version 0.014 of Reindeer::Util - released August 31, 2012 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -214,7 +218,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
